Exception: Api2Convert::SignatureVerificationError
- Defined in:
- lib/api2convert/errors.rb
Overview
A webhook payload could not be verified against the provided signature/secret.
Treat this as a security event: do not trust or process the payload.
A webhook payload could not be verified against the provided signature/secret.
Treat this as a security event: do not trust or process the payload.